/*
	ef_PasteAsSelected_Additive
	
	Pastes and selects pasted geometry. Selection is additive, meaning
	it will not clear previous selection, but simply add to it.
	
	Use at own risk.
	
	author Dan Dulberger evenflcw@yahoo.com
	
	version log
	v1.1 (2011-12-06)	-Initial release. Based on ef_PasteAsSelected v1.1.
*/
@script modeler
@version 2.7
@name PasteAsSelected_Additive

@define	POINT_MODE 	 1 
@define POLYGON_MODE 2

@define ADDITIVE_SELECTION 1

main {

	mesh = Mesh(0);
	layers = lyrfg(); 
	
	undogroupbegin();
	{
		pntcnt_before = layerpointcount(mesh, layers[1]); //LW pastes into primary layer, so that's what we have to keep count on.
		polcnt_before = layerpolycount(mesh, layers[1]);
		
		paste();
		
		pntcnt_after = layerpointcount(mesh, layers[1]);
		polcnt_after = layerpolycount(mesh, layers[1]);
		
		mode = polcnt_after > polcnt_before ? POLYGON_MODE : pntcnt_after > pntcnt_before ? POINT_MODE : 0;
		
		selmode(USER);
		switch(mode) {
		
			case POLYGON_MODE:
				if(!ADDITIVE_SELECTION) selpolygon(CLEAR);
				select_polygons(polcnt_before+1, polcnt_after);
				set_selection_mode(POLYGON_MODE);
				break;
			
			case POINT_MODE:
				if(!ADDITIVE_SELECTION) selpoint(CLEAR);
				select_points(pntcnt_before+1, pntcnt_after);
				set_selection_mode(POINT_MODE);
				break;
				
			default:
				//ie value is 0, nothing to do, nothing was pasted.
				break;
		}
	}
	undogroupend();
	
}

set_selection_mode: element_type {
	switch(element_type)
	{
		case POINT_MODE:
			selpoint(SET, NPEQ, -1);
			break;
		
		case POLYGON_MODE:
			selpolygon(SET, NVEQ, 0);
			break;
	}
}

select_polygons: ndx_start, ndx_end
{
	var elements[ndx_end-ndx_start+1];
	for(i=1, n=ndx_start; n<=ndx_end; i++, n++)
	{
		elements[i] = n;
	}
	selpolygon(SET, POLYNDX, elements);
}

select_points: ndx_start, ndx_end
{
	var elements[ndx_end-ndx_start+1];
	for(i=1, n=ndx_start; n<=ndx_end; i++, n++)
	{
		elements[i] = n;
	}
	selpoint(SET, POINTNDX, elements);
}

globalpointcount {
	selmode(GLOBAL);
	gcount = pointcount();
	return gcount;
}

globalpolycount {
	selmode(GLOBAL);
	(gcount,,,,,) = polycount();
	return gcount;
}

layerpointcount: mesh, layer_index {
	count = mesh.pointCount(layer_index);
	if(count==1) { //bug handling, pointCount/polygonCount method will return 1 for empty layer.
		empty_layers = lyremptyfg();
		if(empty_layers.contains(layer_index)) {
			count = 0;
		}
	}
	return count;
}

layerpolycount: mesh, layer_index {
	count = mesh.polygonCount(layer_index);
	if(count==1) { //bug handling, pointCount/polygonCount method will return 1 for empty layer.
		empty_layers = lyremptyfg();
		if(empty_layers.contains(layer_index)) {
			count = 0;
		}
	}
	return count;
}

selpointcount {
	selmode(USER);
	ucount = pointcount();
	selmode(DIRECT);
	dcount = pointcount();
	
	if(ucount==dcount) return ucount;
	else return 0;
}

selpolycount {
//handles situation were selmode:direct will indicate polygons selected in pointmode
	selmode(USER);
	(ucount,,,,,) = polycount();
	selmode(DIRECT);
	(dcount,,,,,) = polycount();
	
	if(ucount==dcount) return ucount;
	else return 0;
}
